Stan Math Library: stan/math/rev/scal.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

scal.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_HPP
2 #define STAN_MATH_REV_SCAL_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/rev/scal/meta/is_var.hpp>
6 #include <stan/math/rev/scal/meta/partials_type.hpp>
7 #include <stan/math/rev/scal/meta/OperandsAndPartials.hpp>
8
9 #include <stan/math/prim/scal.hpp>
10
11 #include <stan/math/rev/scal/fun/abs.hpp>
12 #include <stan/math/rev/scal/fun/acos.hpp>
13 #include <stan/math/rev/scal/fun/acosh.hpp>
14 #include <stan/math/rev/scal/fun/as_bool.hpp>
15 #include <stan/math/rev/scal/fun/asin.hpp>
16 #include <stan/math/rev/scal/fun/asinh.hpp>
17 #include <stan/math/rev/scal/fun/atan.hpp>
18 #include <stan/math/rev/scal/fun/atan2.hpp>
19 #include <stan/math/rev/scal/fun/atanh.hpp>
20 #include <stan/math/rev/scal/fun/bessel_first_kind.hpp>
21 #include <stan/math/rev/scal/fun/bessel_second_kind.hpp>
22 #include <stan/math/rev/scal/fun/binary_log_loss.hpp>
23 #include <stan/math/rev/scal/fun/boost_fpclassify.hpp>
24 #include <stan/math/rev/scal/fun/boost_isfinite.hpp>
25 #include <stan/math/rev/scal/fun/boost_isinf.hpp>
26 #include <stan/math/rev/scal/fun/boost_isnan.hpp>
27 #include <stan/math/rev/scal/fun/boost_isnormal.hpp>
28 #include <stan/math/rev/scal/fun/calculate_chain.hpp>
29 #include <stan/math/rev/scal/fun/cbrt.hpp>
30 #include <stan/math/rev/scal/fun/ceil.hpp>
31 #include <stan/math/rev/scal/fun/cos.hpp>
32 #include <stan/math/rev/scal/fun/cosh.hpp>
33 #include <stan/math/rev/scal/fun/digamma.hpp>
34 #include <stan/math/rev/scal/fun/erf.hpp>
35 #include <stan/math/rev/scal/fun/erfc.hpp>
36 #include <stan/math/rev/scal/fun/exp.hpp>
37 #include <stan/math/rev/scal/fun/exp2.hpp>
38 #include <stan/math/rev/scal/fun/expm1.hpp>
39 #include <stan/math/rev/scal/fun/fabs.hpp>
40 #include <stan/math/rev/scal/fun/falling_factorial.hpp>
41 #include <stan/math/rev/scal/fun/fdim.hpp>
42 #include <stan/math/rev/scal/fun/floor.hpp>
43 #include <stan/math/rev/scal/fun/fma.hpp>
44 #include <stan/math/rev/scal/fun/fmax.hpp>
45 #include <stan/math/rev/scal/fun/fmin.hpp>
46 #include <stan/math/rev/scal/fun/fmod.hpp>
47 #include <stan/math/rev/scal/fun/gamma_p.hpp>
48 #include <stan/math/rev/scal/fun/gamma_q.hpp>
49 #include <stan/math/rev/scal/fun/grad_inc_beta.hpp>
50 #include <stan/math/rev/scal/fun/hypot.hpp>
51 #include <stan/math/rev/scal/fun/ibeta.hpp>
52 #include <stan/math/rev/scal/fun/if_else.hpp>
53 #include <stan/math/rev/scal/fun/inc_beta.hpp>
54 #include <stan/math/rev/scal/fun/inv.hpp>
55 #include <stan/math/rev/scal/fun/inv_cloglog.hpp>
56 #include <stan/math/rev/scal/fun/inv_logit.hpp>
57 #include <stan/math/rev/scal/fun/inv_Phi.hpp>
58 #include <stan/math/rev/scal/fun/inv_sqrt.hpp>
59 #include <stan/math/rev/scal/fun/inv_square.hpp>
60 #include <stan/math/rev/scal/fun/is_inf.hpp>
61 #include <stan/math/rev/scal/fun/is_nan.hpp>
62 #include <stan/math/rev/scal/fun/is_uninitialized.hpp>
63 #include <stan/math/rev/scal/fun/lgamma.hpp>
64 #include <stan/math/rev/scal/fun/lmgamma.hpp>
65 #include <stan/math/rev/scal/fun/log.hpp>
66 #include <stan/math/rev/scal/fun/log10.hpp>
67 #include <stan/math/rev/scal/fun/log1m.hpp>
68 #include <stan/math/rev/scal/fun/log1m_exp.hpp>
69 #include <stan/math/rev/scal/fun/log1p.hpp>
70 #include <stan/math/rev/scal/fun/log1p_exp.hpp>
71 #include <stan/math/rev/scal/fun/log2.hpp>
72 #include <stan/math/rev/scal/fun/log_diff_exp.hpp>
73 #include <stan/math/rev/scal/fun/log_falling_factorial.hpp>
74 #include <stan/math/rev/scal/fun/log_mix.hpp>
75 #include <stan/math/rev/scal/fun/log_rising_factorial.hpp>
76 #include <stan/math/rev/scal/fun/log_sum_exp.hpp>
77 #include <stan/math/rev/scal/fun/modified_bessel_first_kind.hpp>
78 #include <stan/math/rev/scal/fun/modified_bessel_second_kind.hpp>
79 #include <stan/math/rev/scal/fun/multiply_log.hpp>
80 #include <stan/math/rev/scal/fun/owens_t.hpp>
81 #include <stan/math/rev/scal/fun/Phi.hpp>
82 #include <stan/math/rev/scal/fun/Phi_approx.hpp>
83 #include <stan/math/rev/scal/fun/pow.hpp>
84 #include <stan/math/rev/scal/fun/primitive_value.hpp>
85 #include <stan/math/rev/scal/fun/rising_factorial.hpp>
86 #include <stan/math/rev/scal/fun/round.hpp>
87 #include <stan/math/rev/scal/fun/sin.hpp>
88 #include <stan/math/rev/scal/fun/sinh.hpp>
89 #include <stan/math/rev/scal/fun/sqrt.hpp>
90 #include <stan/math/rev/scal/fun/square.hpp>
91 #include <stan/math/rev/scal/fun/step.hpp>
92 #include <stan/math/rev/scal/fun/tan.hpp>
93 #include <stan/math/rev/scal/fun/tanh.hpp>
94 #include <stan/math/rev/scal/fun/to_var.hpp>
95 #include <stan/math/rev/scal/fun/tgamma.hpp>
96 #include <stan/math/rev/scal/fun/trunc.hpp>
97 #include <stan/math/rev/scal/fun/value_of.hpp>
98 #include <stan/math/rev/scal/fun/value_of_rec.hpp>
99
100 #endif
inv_cloglog.hpp
cos.hpp
tan.hpp
log10.hpp
binary_log_loss.hpp
Phi_approx.hpp
log_mix.hpp
value_of_rec.hpp
core.hpp
owens_t.hpp
OperandsAndPartials.hpp
gamma_p.hpp
exp.hpp
inv_sqrt.hpp
lmgamma.hpp
is_inf.hpp
if_else.hpp
fmax.hpp
digamma.hpp
inv.hpp
square.hpp
boost_fpclassify.hpp
log_rising_factorial.hpp
is_uninitialized.hpp
expm1.hpp
sinh.hpp
fdim.hpp
tgamma.hpp
acosh.hpp
atan2.hpp
modified_bessel_first_kind.hpp
log_sum_exp.hpp
inv_square.hpp
partials_type.hpp
primitive_value.hpp
sqrt.hpp
ceil.hpp
inv_Phi.hpp
ibeta.hpp
log1p.hpp
inc_beta.hpp
fmod.hpp
asinh.hpp
acos.hpp
round.hpp
log1m_exp.hpp
log1p_exp.hpp
scal.hpp
exp2.hpp
log.hpp
log_diff_exp.hpp
floor.hpp
boost_isfinite.hpp
lgamma.hpp
bessel_second_kind.hpp
log2.hpp
erfc.hpp
to_var.hpp
Phi.hpp
grad_inc_beta.hpp
multiply_log.hpp
boost_isinf.hpp
abs.hpp
boost_isnan.hpp
cosh.hpp
inv_logit.hpp
log1m.hpp
fmin.hpp
as_bool.hpp
hypot.hpp
calculate_chain.hpp
boost_isnormal.hpp
pow.hpp
fabs.hpp
gamma_q.hpp
log_falling_factorial.hpp
step.hpp
atan.hpp
trunc.hpp
is_var.hpp
atanh.hpp
modified_bessel_second_kind.hpp
fma.hpp
cbrt.hpp
tanh.hpp
falling_factorial.hpp
is_nan.hpp
rising_factorial.hpp
bessel_first_kind.hpp
sin.hpp
erf.hpp
value_of.hpp
asin.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.